@@ -6,6 +6,14 @@ mdformats <- function(script, log_html, mdfmt, self, out_dir) {
     x = basename(script)
   )
 
+  supported_formats <- list_pandoc_output_formats()
+  unsupported_formats <- setdiff(mdfmt, supported_formats)
+  if (any(!mdfmt %in% supported_formats)) {
+    cli::cli_abort(
+      "Output format{?s} {.code {unsupported_formats}} not supported by your pandoc installation"
+    )
+  }
+
   if (length(mdfmt) >= 1) {
     newname <- paste0(newname, "_log_", mdfmt)
   }
@@ -31,3 +39,8 @@ mdformats <- function(script, log_html, mdfmt, self, out_dir) {
 
   return(invisible(newname))
 }
+
+#' @noRd
+list_pandoc_output_formats <- function() {
+  system(command = "pandoc --list-output-formats", intern = TRUE)
+}
